Crate ere_macros

Crate ere_macros 

Macros

compile_regex
This is the primary entrypoint to the ere crate. Checks and compiles a regular expression into a Regex<N>.
compile_regex_dfa_u8
Checks and compiles a regular expression into a into a ere_core::Regex<N> with the ere_core::dfa_u8 engine. Unless you specifically want this engine, you might want to use compile_regex! instead.
compile_regex_fixed_offset
Checks and compiles a regular expression into a ere_core::Regex<N> with the ere_core::fixed_offset engine. Unless you specifically want this engine, you might want to use compile_regex! instead.
compile_regex_flat_lockstep_nfa
Checks and compiles a regular expression into a into a ere_core::Regex<N> with the ere_core::flat_lockstep_nfa engine. Unless you specifically want this engine, you might want to use compile_regex! instead.
compile_regex_flat_lockstep_nfa_u8
Checks and compiles a regular expression into a into a ere_core::Regex<N> with the ere_core::flat_lockstep_nfa_u8 engine. Unless you specifically want this engine, you might want to use compile_regex! instead.
compile_regex_u8onepass
Checks and compiles a regular expression into a ere_core::Regex<N> with the ere_core::one_pass_u8 engine. Unless you specifically want this engine, you might want to use compile_regex! instead.