Crate ere_macros

Crate ere_macros 

Macros

compile_regex
This is the primary entrypoint to the ere crate. Checks and compiles a regular expression into a Regex<N>.
compile_regex_fixed_offset
Checks and compiles a regular expression into a ere_core::Regex<N> with the ere_core::fixed_offset engine. Unless you specifically want this engine, you might want to use compile_regex! instead.
compile_regex_pikevm
Checks and compiles a regular expression into a into a ere_core::Regex<N> with the ere_core::pike_vm engine. Unless you specifically want this engine, you might want to use compile_regex! instead.
compile_regex_u8onepass
Checks and compiles a regular expression into a ere_core::Regex<N> with the ere_core::one_pass_u8 engine. Unless you specifically want this engine, you might want to use compile_regex! instead.
compile_regex_u8pikevm
Checks and compiles a regular expression into a into a ere_core::Regex<N> with the ere_core::pike_vm_u8 engine. Unless you specifically want this engine, you might want to use compile_regex! instead.