Macros
- compile_
regex - This is the primary entrypoint to the
erecrate. Checks and compiles a regular expression into aRegex<N>. - compile_
regex_ fixed_ offset - Checks and compiles a regular expression into a
ere_core::Regex<N>with theere_core::fixed_offsetengine. Unless you specifically want this engine, you might want to usecompile_regex!instead. - compile_
regex_ pikevm - Checks and compiles a regular expression into a into a
ere_core::Regex<N>with theere_core::pike_vmengine. Unless you specifically want this engine, you might want to usecompile_regex!instead. - compile_
regex_ u8onepass - Checks and compiles a regular expression into a
ere_core::Regex<N>with theere_core::one_pass_u8engine. Unless you specifically want this engine, you might want to usecompile_regex!instead. - compile_
regex_ u8pikevm - Checks and compiles a regular expression into a into a
ere_core::Regex<N>with theere_core::pike_vm_u8engine. Unless you specifically want this engine, you might want to usecompile_regex!instead.